@@ -15,14 +15,14 @@ def main(args):
     field = args[3]
     value = int(args[4])
 
-    assert field in ['minimum', 'maximum', 'resolution']
+    assert field in ["minimum", "maximum", "resolution"]
     axis = libevdev.evbit(axis)
     assert axis is not None
 
-    fd = open(path, 'rb')
+    fd = open(path, "rb")
     d = libevdev.Device(fd)
     if not d.has(axis):
-        print('Device does not have axis {}'.format(axis))
+        print("Device does not have axis {}".format(axis))
         sys.exit(1)
 
     a = d.absinfo[axis]
