@@ -19,6 +19,8 @@
 # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 # DEALINGS IN THE SOFTWARE.
 
+from __future__ import annotations
+
 import libevdev
 
 import os
@@ -31,7 +33,12 @@ from ctypes import c_void_p
 from ctypes import c_long
 from ctypes import c_int32
 from ctypes import c_uint16
-from typing import BinaryIO, Tuple, Self
+from typing import BinaryIO, Tuple
+
+try:
+    from typing import Self
+except ImportError:
+    from typing_extensions import Self
 
 
 READ_FLAG_SYNC = 0x1
